import { compile as platformCompile } from '@lwc/sfdc-lwc-compiler';
import { Workspace } from '../../types/index';
import { compile } from './lexBundler';
vi.mock('@lwc/sfdc-lwc-compiler');
describe('compile', () => {
    let mockCtx;
    let mockLogger;
    const mockModulePath = 'src/modules/myModule';
    const mockTransformOptions = {
        enableDynamicComponents: true,
        enableLightningWebSecurityTransforms: true,
        experimentalComplexExpressions: true,
        apiVersion: 50,
        name: 'myModule',
        namespace: 'c',
    };
    beforeEach(() => {
        mockLogger = {
            log: vi.fn(),
        };
        mockCtx = {
            config: {
                workspace: Workspace.Internal,
            },
            moduleGraph: {
                getModuleFiles: vi.fn().mockReturnValue(['file1', 'file2']),
            },
        };
        vi.clearAllMocks();
    });
    it('should compile successfully and return code and warnings', async () => {
        const mockResult = {
            success: true,
            results: [
                {
                    code: 'compiled code',
                    map: '',
                    imports: [],
                    diagnostics: [],
                    outputConfig: {
                        minify: false,
                        sourcemap: false,
                        lockerConfig: {},
                        env: { NODE_ENV: 'dev' },
                    },
                    timings: {},
                },
            ],
            diagnostics: [],
            timings: {},
            version: '1',
        };
        vi.mocked(platformCompile).mockResolvedValue(mockResult);
        const result = await compile(mockCtx, mockModulePath, mockTransformOptions, mockLogger);
        expect(platformCompile).toHaveBeenCalledWith(expect.any(Object));
        expect(result.code).toBe('compiled code');
        expect(result.warnings).toEqual([]);
    });
    it('should return undefined code and warnings when compilation fails', async () => {
        vi.mocked(platformCompile).mockResolvedValue({
            success: false,
            results: [],
            diagnostics: [],
            version: '1',
            timings: {},
        });
        const result = await compile(mockCtx, mockModulePath, mockTransformOptions, mockLogger);
        expect(result.code).toBeUndefined();
    });
});
//# sourceMappingURL=lexBundler.spec.js.map