import { FSWatcher } from 'chokidar';
import { ServerConfig, type Logger } from '../../types/index.js';
import type { HMR_Data_Register } from '@lwc/lwc-dev-server-types';
import type { ModuleInfo, ModuleMapEntry, WorkspaceScanner } from './workspaceScanner/scanner';
import type { BundleFiles } from '@lwc/sfdc-lwc-compiler/dist/compile.js';
export type Module = any;
export interface ModuleChangeCallbacks {
    moduleUpdateHandler: (modulePath: string) => void;
}
export declare class ModuleGraph {
    logger: Logger;
    watcher: FSWatcher;
    workspaceScanner: WorkspaceScanner;
    /**
     * All LWC modules and their parts with absolute file paths, for the current workspace.
     */
    moduleMap: Map<string, ModuleMapEntry>;
    /**
     * All modules paths that are being used by the various client connections
     */
    activeModulePaths: string[];
    fileToModulePathMap: {
        [key: string]: string;
    };
    modulePathToModuleInfo: {
        [key: string]: ModuleInfo;
    };
    moduleChangeCallbacks: ModuleChangeCallbacks;
    constructor(config: ServerConfig, logger: Logger, watcher: FSWatcher, moduleChangeCallbacks: ModuleChangeCallbacks);
    init(): void;
    getModulePathByFile(path: string): string | undefined;
    getFileByModulePath(modulePath: string): string | undefined;
    /**
     * Register the active paths that the client is interested in
     * @param moduleRegistration
     * @returns Modules paths that are determined to be stale wrt the content monitored by the dev server
     */
    registerActivePaths(moduleRegistration: HMR_Data_Register): string[];
    fileChangeHandler(filePath: string): void;
    /**
     * Identify which modulePath that represents the boundary of the changed module.
     * In the case of .html files, the module boundary is the template file itself. swapTemplate()
     *  is called and module swap is done.
     * In the case of .css files, the module boundary is the css file itself, swapStyle() is called
     *  and module swap is done.
     * In the case of .js files, the module boundary is the main entry file of the module, all the files
     *  reachable from the entry module are bundled and swapComponent invoked.
     *  Since JS hot swap is currently supporting components, this focused update of the main entry file
     *  is acceptable.
     * @param modulePath The module that changed
     * @return The modulePath of the boundary that needs to be updated.
     */
    getModuleBoundary(modulePath: string): string;
    /**
     * Fetch files and source related to the modulePath that is being hot loaded.
     * @param {string} name Name of the component being compiled
     * @param {string} namespace The namespace of the component
     * @param {string} modulePath The formatted path for the file being compiled.
     * @returns
     */
    getModuleFiles(name: string, namespace: string, modulePath: string): BundleFiles;
}
