import path from 'node:path';
import { getComponentParts } from './fileReader.js';
export class BaseWorkspaceScanner {
    constructor(workspace, modulesPaths, logger, excludePaths) {
        this.workspace = workspace;
        this.modulesPaths = modulesPaths;
        this.excludePaths = excludePaths;
        this.logger = logger;
    }
    /**
     * Get information about LWC modules contained in the workspace.
     */
    getModulesMap() {
        const modulesMap = new Map();
        this.findModuleDirs().forEach((dir) => {
            const moduleMapEntry = this.scanAModule(dir);
            if (moduleMapEntry) {
                modulesMap.set(moduleMapEntry.ownerModuleId, moduleMapEntry);
            }
        });
        return modulesMap;
    }
    scanAModule(moduleDir) {
        const { base } = path.parse(moduleDir);
        const namespace = this.getNamespace(moduleDir);
        const ownerModuleId = `${namespace}/${base}`;
        const moduleParts = getComponentParts(moduleDir, namespace, ownerModuleId);
        if (!moduleParts) {
            return;
        }
        const moduleMap = {
            ownerModuleId,
            moduleParts,
        };
        return moduleMap;
    }
}
//# sourceMappingURL=scanner.js.map